@@ -10,6 +10,7 @@ from plone.restapi.testing import PloneRestApiDXLayer
 from plone.testing import z2
 from zope.globalrequest import setRequest
 
+import collective.dexteritytextindexer
 import collective.folderishtypes
 import collective.MockMailHost
 import collective.venue
@@ -18,6 +19,7 @@ import collective.volto.dropdownmenu
 import collective.volto.formsupport
 import collective.volto.secondarymenu
 import collective.volto.socialsettings
+import collective.volto.subfooter
 import collective.volto.subsites
 import design.plone.contenttypes
 import design.plone.policy
@@ -58,6 +60,8 @@ class DesignPlonePolicyLayer(PloneSandboxLayer):
         self.loadZCML(package=redturtle.bandi)
         self.loadZCML(package=redturtle.volto)
         self.loadZCML(package=redturtle.voltoplugin.editablefooter)
+        self.loadZCML(package=collective.dexteritytextindexer)
+        self.loadZCML(package=collective.volto.subfooter)
 
     def setUpPloneSite(self, portal):
         request = FauxRequest()
@@ -96,9 +100,7 @@ class DesignPlonePolicyRestApiLayer(PloneRestApiDXLayer):
     defaultBases = (PLONE_APP_CONTENTTYPES_FIXTURE,)
 
     def setUpZope(self, app, configurationContext):
-        super(DesignPlonePolicyRestApiLayer, self).setUpZope(
-            app, configurationContext
-        )
+        super(DesignPlonePolicyRestApiLayer, self).setUpZope(app, configurationContext)
 
         self.loadZCML(package=collective.folderishtypes)
         self.loadZCML(package=collective.MockMailHost)
@@ -117,6 +119,7 @@ class DesignPlonePolicyRestApiLayer(PloneRestApiDXLayer):
         self.loadZCML(package=redturtle.bandi)
         self.loadZCML(package=redturtle.volto)
         self.loadZCML(package=redturtle.voltoplugin.editablefooter)
+        self.loadZCML(package=collective.volto.subfooter)
 
     def setUpPloneSite(self, portal):
         request = FauxRequest()
